==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPlaneSource.java <==
// java wrapper for vtkPlaneSource object
//

package vtk;
import vtk.*;

public class vtkPlaneSource extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetXResolution_2(int id0);
  public void SetXResolution(int id0)
    { SetXResolution_2(id0); }

  private native int GetXResolution_3();
  public int GetXResolution()
    { return GetXResolution_3(); }

  private native void SetYResolution_4(int id0);
  public void SetYResolution(int id0)
    { SetYResolution_4(id0); }

  private native int GetYResolution_5();
  public int GetYResolution()
    { return GetYResolution_5(); }

  private native void SetResolution_6(int id0,int id1);
  public void SetResolution(int id0,int id1)
    { SetResolution_6(id0,id1); }

  private native void SetOrigin_7(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_7(id0,id1,id2); }

  private native void SetOrigin_8(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_8(id0); }

  private native double[] GetOrigin_9();
  public double[] GetOrigin()
    { return GetOrigin_9(); }

  private native void SetPoint1_10(double id0,double id1,double id2);
  public void SetPoint1(double id0,double id1,double id2)
    { SetPoint1_10(id0,id1,id2); }

  private native void SetPoint1_11(double id0[]);
  public void SetPoint1(double id0[])
    { SetPoint1_11(id0); }

  private native double[] GetPoint1_12();
  public double[] GetPoint1()
    { return GetPoint1_12(); }

  private native void SetPoint2_13(double id0,double id1,double id2);
  public void SetPoint2(double id0,double id1,double id2)
    { SetPoint2_13(id0,id1,id2); }

  private native void SetPoint2_14(double id0[]);
  public void SetPoint2(double id0[])
    { SetPoint2_14(id0); }

  private native double[] GetPoint2_15();
  public double[] GetPoint2()
    { return GetPoint2_15(); }

  private native void SetCenter_16(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_16(id0,id1,id2); }

  private native void SetCenter_17(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_17(id0); }

  private native double[] GetCenter_18();
  public double[] GetCenter()
    { return GetCenter_18(); }

  private native void SetNormal_19(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_19(id0,id1,id2); }

  private native void SetNormal_20(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_20(id0); }

  private native double[] GetNormal_21();
  public double[] GetNormal()
    { return GetNormal_21(); }

  private native void Push_22(double id0);
  public void Push(double id0)
    { Push_22(id0); }

  private native void SetOutputPointsPrecision_23(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_23(id0); }

  private native int GetOutputPointsPrecision_24();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_24(); }

  public vtkPlaneSource() { super(); }

  public vtkPlaneSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkPlaneSource.java <==
// java wrapper for vtkPlaneSource object
//

package vtk;
import vtk.*;

public class vtkPlaneSource extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetXResolution_2(int id0);
  public void SetXResolution(int id0)
    { SetXResolution_2(id0); }

  private native int GetXResolution_3();
  public int GetXResolution()
    { return GetXResolution_3(); }

  private native void SetYResolution_4(int id0);
  public void SetYResolution(int id0)
    { SetYResolution_4(id0); }

  private native int GetYResolution_5();
  public int GetYResolution()
    { return GetYResolution_5(); }

  private native void SetResolution_6(int id0,int id1);
  public void SetResolution(int id0,int id1)
    { SetResolution_6(id0,id1); }

  private native void SetOrigin_7(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_7(id0,id1,id2); }

  private native void SetOrigin_8(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_8(id0); }

  private native double[] GetOrigin_9();
  public double[] GetOrigin()
    { return GetOrigin_9(); }

  private native void SetPoint1_10(double id0,double id1,double id2);
  public void SetPoint1(double id0,double id1,double id2)
    { SetPoint1_10(id0,id1,id2); }

  private native void SetPoint1_11(double id0[]);
  public void SetPoint1(double id0[])
    { SetPoint1_11(id0); }

  private native double[] GetPoint1_12();
  public double[] GetPoint1()
    { return GetPoint1_12(); }

  private native void SetPoint2_13(double id0,double id1,double id2);
  public void SetPoint2(double id0,double id1,double id2)
    { SetPoint2_13(id0,id1,id2); }

  private native void SetPoint2_14(double id0[]);
  public void SetPoint2(double id0[])
    { SetPoint2_14(id0); }

  private native double[] GetPoint2_15();
  public double[] GetPoint2()
    { return GetPoint2_15(); }

  private native void SetCenter_16(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_16(id0,id1,id2); }

  private native void SetCenter_17(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_17(id0); }

  private native double[] GetCenter_18();
  public double[] GetCenter()
    { return GetCenter_18(); }

  private native void SetNormal_19(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_19(id0,id1,id2); }

  private native void SetNormal_20(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_20(id0); }

  private native double[] GetNormal_21();
  public double[] GetNormal()
    { return GetNormal_21(); }

  private native void Push_22(double id0);
  public void Push(double id0)
    { Push_22(id0); }

  private native void SetOutputPointsPrecision_23(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_23(id0); }

  private native int GetOutputPointsPrecision_24();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_24(); }

  public vtkPlaneSource() { super(); }

  public vtkPlaneSource(long id) { super(id); }
  public native long   VTKInit();

}
